import { View, Map, Image, Text } from "@tarojs/components";
import { Button, Col, Dialog, Row, TextArea } from "@nutui/nutui-react-taro";
import { FC, useEffect, useRef, useState } from "react";
import styles from "./AddressSelect.module.less";
import locationImg from "@/assets/images/kitchenWaste/localPoint.png";
import Taro, { requirePlugin } from "@tarojs/taro";
import { baiduLocationAnalysis } from "@/services/kitchenWaste";
import Flex from "../Flex/Flex";

type LocationSelectProps = {
  show: boolean;
  onConfirm: (data: any) => void;
  onCancale: () => void;
};

const AddressSelect: FC<LocationSelectProps> = (props) => {
  const { show, onConfirm, onCancale } = props;

  useEffect(() => {
    Taro.getLocation({
      type: "gcj02",
      success: ({ longitude, latitude }) => {
        setMarketPoint({ longitude, latitude });
        getAnalysisAddress(longitude, latitude);
      },
    });
  }, []);

  const [marketPoint, setMarketPoint] = useState({
    longitude: 104.164987,
    latitude: 30.829873,
  });
  const regionChange = async (e) => {
    if (e.causedBy === "drag") {
      if (e.detail.type === "end") {
        const { longitude, latitude } = e.detail.centerLocation;
        await getAnalysisAddress(longitude, latitude);
        setMarketPoint({ longitude, latitude });
      }
    }
  };

  const [addressInfo, setAddressInfo] = useState<any>({});
  const getAnalysisAddress = async (longitude: number, latitude: number) => {
    return new Promise(async (resolve, _reject) => {
      const res = await baiduLocationAnalysis(longitude, latitude);
      if (res.code === 200) {
        if (res.data.status !== 0) {
          Taro.showToast({ title: "地址解析失败", icon: "none", mask: true });
          return;
        }
        const result = res.data.result;
        const addressInfo = {
          cityCode: "5101",
          cityName: result.addressComponent.city,
          districtCode: result.addressComponent.adcode,
          districtName: result.addressComponent.district,
          streetCode: result.addressComponent.town_code,
          streetName: result.addressComponent.street,
          communityCode: "",
          communityName: "",
          lon: longitude,
          lat: latitude,
          coordinateType: "GCJ-02",
          address: result.formatted_address_poi,
        };
        setAddressInfo(addressInfo);
        resolve(addressInfo);
      }
    });
  };

  const [editShow, setEditShow] = useState(false);
  const [editStr, setEditStr] = useState<string>();
//   const plugin = requirePlugin("QCloudAIVoice");
//   const speechRecognizerManager = useRef<any>(plugin.speechRecognizerManager());
//   const handleAudioToText = () => {
//     speechRecognizerManager.current.start({
//       // 用户参数
//       secretkey: "jBMGtGMBizziAMHuGL9fvuc3D6i49xUk",
//       secretid: "AKIDAIAm7ByVkiPqzrSnreAQP7YhaCXaNt85",
//       appid: 1308579967,
//       // 实时识别接口参数
//       engine_model_type: "16k_zh",
//       filter_punc: 1,
//       filter_modal: 2,
//       word_info: 2,
//     });
//   };
//   const handleCloseAudio = () => {
//     console.log("停止");
//     speechRecognizerManager.current.stop();
//   };
//   // 开始识别
//   speechRecognizerManager.current.OnRecognitionStart = (res) => {
//     console.log("开始识别", res);
//   };
//   // 一句话开始
//   speechRecognizerManager.current.OnSentenceBegin = (res) => {
//     console.log("一句话开始", res);
//   };
//   // 识别变化时
//   speechRecognizerManager.current.OnRecognitionResultChange = (res) => {
//     console.log("识别变化", res);
//     if (res.code === 0) {
//       const text = res.result.voice_text_str;
//       setEditStr((val) => val + text.slice(0, 100));
//     }
//   };
//   // 一句话结束
//   speechRecognizerManager.current.OnSentenceEnd = (res) => {
//     console.log("一句话结束", res.result.voice_text_str);
//   };
//   // 识别结束
//   speechRecognizerManager.current.OnRecognitionComplete = (res) => {
//     console.log("识别结束", res);
//   };
//   // 识别错误
//   speechRecognizerManager.current.OnError = (res) => {
//     // code为6001时，国内站用户请检查是否使用境外代理，如果使用请关闭。境外调用需开通国际站服务
//     console.log("识别失败", res);
//   };
//   // 录音结束（最长10分钟）时回调
//   speechRecognizerManager.current.OnRecorderStop = (res) => {
//     console.log("录音结束", res);
//   };

  return (
    <View
      className={styles.mapBox}
      style={{ display: `${show ? "block" : "none"}` }}
    >
      <Map
        style={{ width: "100%", height: "100%" }}
        longitude={104.164987}
        latitude={30.829873}
        markers={[
          {
            id: 1,
            longitude: Number(marketPoint?.longitude),
            latitude: Number(marketPoint?.latitude),
            iconPath: locationImg,
            width: "76rpx",
            height: "100rpx",
          },
        ]}
        onRegionChange={regionChange}
        setting={{}}
        onError={() => {}}
      />
      <View className={styles.drag}>
        {/* <Image src={require('@/assets/image/discover/dragPoint.png')} className={styles["drag-img"]} /> */}
      </View>
      <View className={styles["bottom-confrim"]}>
        <View>
          {/* <Image src={require('@/assets/image/discover/location.png')} className={styles.icon} /> */}
          {addressInfo?.address}
          {`（${addressInfo?.streetName || ""}）`}
          <Text
            className={styles.editTxt}
            onClick={() => {
              setEditStr(addressInfo?.address);
              setEditShow(true);
            }}
          >
            编辑地址
          </Text>
        </View>

        <Flex gap={20}>
          <Button
            style={{ flex: 1 }}
            type="info"
            size="large"
            onClick={() => {
              onConfirm(addressInfo);
            }}
          >
            确认位置
          </Button>
          <Button
            style={{ flex: 1 }}
            size="large"
            color="#cccccc"
            onClick={() => {
              onCancale();
            }}
          >
            取消
          </Button>
        </Flex>
      </View>
      <Dialog
        title={<Text className={styles.title}>位置信息</Text>}
        visible={editShow}
        style={{ zIndex: 999999 }}
        closeOnOverlayClick={false}
        footer={
          <Row gutter="10">
            {/* <Col span="12">
                    <Button
                        type="info"
                        className={styles.audio}
                        icon={<img className={styles["audio-icon"]} src={require(`@/assets/image/audio.png`)} />}
                        onTouchStart={handleAudioToText}
                        onTouchEnd={handleCloseAudio}
                    >按住说话</Button>
                </Col> */}
            <Col span="24">
              <Button
                type="info"
                className={styles.btn}
                onClick={() => {
                  if (!editStr) {
                    Taro.showToast({ title: "请输入位置信息", icon: "none" });
                    return;
                  }
                  addressInfo.address = editStr;
                  setAddressInfo({ ...addressInfo });
                  setEditShow(false);
                }}
              >
                完成
              </Button>
            </Col>
          </Row>
        }
        onConfirm={() => setEditShow(false)}
        onCancel={() => setEditShow(false)}
      >
        <TextArea
          placeholder="请输入位置信息"
          maxLength={100}
          showCount
          className={styles["text-area"]}
          rows={1}
          value={editStr}
          onChange={(value) => setEditStr(value)}
        />
      </Dialog>
    </View>
  );
};

export default AddressSelect;
