import { EventProps, View } from "@tarojs/components"
import { FC } from "react"
import styles from './Flex.module.less'

type FlexProps = {
    style?: React.CSSProperties
    className?: string
    vertical?: boolean;
    wrap?: boolean | React.CSSProperties['flexWrap'];
    justify?: React.CSSProperties['justifyContent'];
    align?: React.CSSProperties['alignItems'];
    flex?: React.CSSProperties['flex'];
    gap?: React.CSSProperties['gap']
    children: React.ReactNode;
    onClick?: EventProps['onClick']
}
const Flex: FC<FlexProps> = (props) => {
    const { gap, children, flex, align, justify, wrap, vertical, className, style, onClick } = props
    const flexWrap = typeof wrap === 'boolean' ? 'wrap' : wrap
    return <View
        onClick={onClick}
        className={`${styles.flex} ${className}`}
        style={{
            display: 'flex',
            gap, flex,
            alignItems: align,
            justifyContent: justify,
            flexWrap,
            flexDirection: vertical ? 'column' : 'row',
            ...style
        }}>
        {children}
    </View>
}

export default Flex