import { Canvas } from "@tarojs/components"
import Taro from "@tarojs/taro";
import { forwardRef, useImperativeHandle, useState } from "react";

type RotatingCanvasProps = {

}
export type RotatingCanvasRef = {
    rotateImage: (image: string, angle: 90 | -90) => Promise<string>
}

const canvasId = 'RotatingCanvas'
const RotatingCanvas = forwardRef<RotatingCanvasRef, RotatingCanvasProps>((_props, ref) => {

    const [canvasData, setCanvasData] = useState({
        width: '0px',
        height: '0px',
    })
    const rotateImage: RotatingCanvasRef['rotateImage'] = (image, angle) => {
        Taro.showLoading({ title: '正在加载', mask: true })
        return new Promise((resolve) => {
            const ctx = Taro.createCanvasContext(canvasId)
            Taro.getImageInfo({
                src: image,
                success: ({ width, height, path }) => {
                    let w = 0
                    let h = 0
                    if (Math.abs(angle) === 90) {
                        w = height
                        h = width
                    } else {
                        w = width
                        h = height
                    }
                    setCanvasData({ width: w + 'px', height: h + 'px' })
                    if (angle === 90) {
                        ctx.translate(w, 0)
                        ctx.rotate(Math.PI / 2)
                    }
                    if (angle === -90) {
                        ctx.translate(0, h)
                        ctx.rotate(-Math.PI / 2)
                    }
                    ctx.drawImage(path, 0, 0)
                    setTimeout(() => {
                        ctx.draw(false, () => {
                            Taro.canvasToTempFilePath({
                                canvasId,
                                x: 0,
                                y: 0,
                                width: w,
                                height: h,
                                destWidth: w,
                                destHeight: h,
                                fileType: 'jpg',
                                quality: 0.2,
                                success: async (res) => {
                                    setTimeout(() => {
                                        console.log(res);
                                        Taro.showLoading()
                                        resolve(res.tempFilePath)
                                    }, 200)
                                },
                                fail: (err) => {
                                    console.log(err)
                                }
                            })
                        })
                    }, 200)
                }
            })
        })
    }

    useImperativeHandle(ref, () => {
        return {
            rotateImage
        }
    })

    return <Canvas
        canvasId={canvasId}
        style={{
            position: 'fixed',
            // left: 0,
            // top: 0,
            // zIndex: 10,
            left: '-10000000px',
            top: '-10000000px',
            zIndex: -10,
            width: canvasData.width,
            height: canvasData.height
        }}
    />

})

export default RotatingCanvas