import { FC, useEffect, useRef, useState } from "react"
import Flex from "@/components/Flex/Flex"
import { ScrollView, Button } from "@tarojs/components"
import Taro from "@tarojs/taro"
import styles from './WayPopup.module.less'
import { Popup } from "@taroify/core"
import { wayPageList } from "@/services/event"

type WayPopupProps = {
    visible: boolean
    onClose: () => void
    onSubmit: (data: { label: string, value: string }) => void
}
type itemType = { label: string, value: string }
const WayPopup: FC<WayPopupProps> = (props) => {
    const { visible, onClose, onSubmit } = props

    const [list, setList] = useState<itemType[]>([])
    const page = useRef(1)
    const total = useRef(0)
    const getWayList = async (searchText: string = '') => {
        const res = await wayPageList({
            // page: page.current,
            // count: 1000,
            searchText
        })
        if (res.code === 200) {
            total.current = Number(res.data.total)
            const newList = res.data
            if (page.current === 1) {
                setList(newList)
            } else {
                setList([...list, ...newList])
            }
        }
    }

    const [activeIndex, setActiveIndex] = useState(-1)

    const submitData = () => {
        if (list.length !== 0 && activeIndex === -1) {
            Taro.showToast({ title: '请选择街道', icon: 'none', mask: true })
            return
        }
        onSubmit(list[activeIndex])
        onClose()
    }
    useEffect(() => {
        getWayList('')
    }, [])

    return <Popup
        open={visible}
        onClose={onClose}
        placement="bottom"
        style={{ padding: '25px' }}
        rounded
    >
        {/* <Flex align="center" gap={10} justify='space-between' style={{ marginBottom: 10 }}>
            <Flex className={styles.inpBox} gap={10}>
                <Input
                    focus={visible}
                    className={styles.inp}
                    placeholder="街道关键字搜索"
                    onInput={(e) => searchTextChange(e.detail.value)}
                    adjustPosition={false}
                />
            </Flex>
            <Button className={styles.subBtn} onClick={submitData}>确定</Button>
        </Flex> */}
        <ScrollView className={styles.scrollBox} scrollY>
            {list.map(({ label, value }, index) => {
                return <Flex className={`${styles.item} ${index === activeIndex ? styles.active : ''}`} key={value} onClick={() => {
                    setActiveIndex(index)
                }}>{label}</Flex>
            })}
        </ScrollView>
        <Button className={styles.subBtn} onClick={submitData}>确定</Button>
    </Popup>
}

export default WayPopup