import { ITouch, View } from "@tarojs/components";
import { CSSProperties, FC, memo, useCallback, useRef } from "react"
import { throttle } from "lodash";

type ZoomViewProps = {
    width: CSSProperties['width']
    height: CSSProperties['height']
    zIndex?: CSSProperties['zIndex']
    onZoom?: (zoom: number) => void
}

const getDistance = (arr1, arr2) => {//计算缩放
    if (arr1 && arr2) {
        let x = arr2.pageX - arr1.pageX;
        let y = arr2.pageY - arr1.pageY;
        return (x * x) + (y * y);
    } else {
        return 1
    }
}

const ZoomView: FC<ZoomViewProps> = memo((props) => {
    const { width, height, zIndex = 2, onZoom } = props
    const nowZoom = useRef(1)  // 手势停止时的zoom

    const realTimeZoom = useRef(1)  // 手势变化时的实时zoom
    const touchStart = useRef<ITouch[]>([])
    const touchStartCallback = (e) => {
        if (e.touches.length === 2) {
            touchStart.current = e.touches
        }
    }

    const touchMoveCallback = useCallback(throttle((e) => {
        if (e.changedTouches.length === 2) {
            const now = e.changedTouches;
            const now1 = getDistance(now[0], now[1]);
            const now2 = getDistance(touchStart.current[0], touchStart.current[1]);
            realTimeZoom.current = now1 / now2 * nowZoom.current
            onZoom && onZoom(realTimeZoom.current)
        }
    }, 10), [])
    return <View
        onTouchStart={(e) => touchStartCallback(e)}
        onTouchEnd={() => {
            nowZoom.current = realTimeZoom.current
        }}
        onTouchMove={(e) => touchMoveCallback(e)}
        style={{
            width,
            height,
            zIndex,
            backgroundColor: 'transparent',
            position: 'absolute',
            top: 0,
            left: 0
        }}
    />
})

export default ZoomView

