//获取位置信息和地址
import { getAuth } from '@/utils/comm';
import Taro from '@tarojs/taro';
interface AddressInfo {
  cityCode: string;
  cityName: string;
  districtCode: string;
  districtName: string;
  streetCode: string;
  streetName: string;
  communityCode: string;
  communityName: string;
  lon: number;
  lat: number;
  coordinateType: string;
  address: string;
}

function useMapLocation() {
  const getLocationAndAddress = async () => {
    try {
      const auth = await getAuth('scope.userLocation','请打开位置权限',()=>{
        Taro.navigateBack()
      })
      if(!auth){
        throw '请打开位置权限'
      }
      const res = await Taro.getLocation({ type: 'gcj02' }).catch(()=>{
        Taro.showModal({
          title: '提示',
          content: '请打开手机位置信息',
          confirmText: "确定",
          showCancel: false,
          complete: () => {
            Taro.navigateBack()
          }
        })
      })
      if(!res)return
      const { latitude, longitude } = res; 
      const response = await Taro.request({
        url: `https://apis.map.qq.com/ws/geocoder/v1?location=${latitude},${longitude}&key=ZCMBZ-EMXKZ-GQEXH-TQNKQ-IHFAO-KQF3S`,
        method: 'GET',
        success: (res) => res,
        fail: (err) => {
          console.error('获取失败:', err);
        },
      });

      const { status, result } = response.data;
      if (status !== 0) {
        console.log(response);
        throw new Error('解析失败');
      }

      const addressInfo: AddressInfo = {
        cityCode: '5101',
        cityName: result.address_component.city,
        districtCode: result.ad_info.adcode,
        districtName: result.ad_info.district,
        streetCode: result.address_reference?.town?.id,
        streetName: result.address_component.street,
        communityCode: '',
        communityName: '',
        lon: result.location.lng, //事件经度
        lat: result.location.lat, //事件纬度
        coordinateType: 'GCJ-02', //坐标类型
        address: result.formatted_addresses.recommend,
      };

      return addressInfo;
    } catch (error) {
      throw error; 
    }
  };

  return { getLocationAndAddress };
}

export default useMapLocation;
