import { ScrollView, View } from "@tarojs/components";
import { ConfigProvider, Empty, Flex, Navbar, Tag } from "@taroify/core";
import './applyRecord.less'
import Taro, { useDidShow, useLoad } from "@tarojs/taro";
import { useState } from "react";
import services from "@/services";
import useGlobalStore from "@/store/useUserStore";

const applyRecord = () => {
    const { updateActionObj } = useGlobalStore();
    const [statusBarHeight, setStatusBarHeight] = useState(0);

    const onBack = () => {
        Taro.navigateBack();
    };
    useLoad(() => {
        const systemInfo = Taro.getSystemInfoSync();
        setStatusBarHeight(systemInfo?.statusBarHeight ?? 0);
    });

    const [paginationInfo, setPaginationInfo] = useState<API.Pagination>();
    const [dataSource, setDataSource] = useState<any[]>([]);


    /** 无限加载 */
    const onScrollToLower = () => {
        if (paginationInfo?.hasNext) {
            getList(paginationInfo?.page + 1);
        } else {
            Taro.showToast({ title: '没有更多了', mask: true, icon: 'none' })
        }
    };
    const getList = async (page: number) => {
        services.report.getApplyRecord({ page, count: 20 }).then((res) => {
            setPaginationInfo(res.data);
            if (page === 1) {
                setDataSource(res.data.list);
            } else {
                setDataSource((prev) => [...prev, ...res.data.list]);
            }
        })
    }

    const [statiscData, setStatiscData] = useState({ total: 0, completed: 0 })
    const getStatisc = async () => {
        const res = await services.report.applyRecordStatisc()
        if (res.code === 200) {
            setStatiscData(res.data)
        }
    }
    useDidShow(() => {
        getList(1);
        getStatisc()
    })

    return <View className="report_container4">
        <View className="decoration" />
        <View style={{ height: statusBarHeight }} />
        <ConfigProvider
            theme={{
                "—navbar-background-color": "transparent",
            }}
        >
            <Navbar safeArea="top">
                <Navbar.NavLeft onClick={onBack}>返回</Navbar.NavLeft>
            </Navbar>
        </ConfigProvider>
        <View className="titleBox">
            <View className="title">申请记录</View>
            <View className="statisc">
                共申请：{statiscData.total}项
            </View>
            <View className="statisc">
                已办结：{statiscData.completed}项
            </View>
        </View>
        <ScrollView
            scrollY
            onScrollToLower={onScrollToLower}
            style={{ height: `calc(100vh - ${statusBarHeight}px - 94px)` }}
        >
            <View className="contentView">
                {dataSource.length === 0 && (
                    <Empty style={{ marginTop: 100 }}>
                        <Empty.Description>暂无记录</Empty.Description>
                    </Empty>
                )}
                {dataSource.map((item) => {
                    return <View
                        key={item.id}
                        className="card"
                        onClick={() => {
                            updateActionObj(item)
                            Taro.navigateTo({
                                url: '/pages/Approve/applyRecordDetail/index?activeTab=1'
                            })
                        }}
                    >
                        <Flex align="center" className="titleContent">
                            <View className="cardTitle">
                                {item?.name}
                            </View>
                            <Tag style={{ whiteSpace: 'nowrap' }} color="primary">{item?.caseStatus.name}</Tag>
                        </Flex>
                        <View className="time">
                            申请时间：{item?.createAt}
                        </View>
                    </View>
                })}
            </View>
        </ScrollView>
    </View>
}

export default applyRecord