import { useMemo } from "react";
import { composeImgUrl } from "@/utils/index";
import { Flex, Empty, Toast, Space } from "@taroify/core";
import { View, Image } from "@tarojs/components";
import DecoratePoint from "@/components/DecoratePoint";
import file from "@/assets/report/file.png";
import imageIcon from "@/assets/report/image.png";
import Taro from "@tarojs/taro";
import { EyeOutlined } from "@taroify/icons";

const Item = ({ label, value }: { label: string; value: string }) => {
  let fileType = "none";

  if (value && value.length > 0) {
    const strList = value?.split(".") ?? [];
    const extra = strList[strList.length - 1];
    // pdf
    if (extra === "pdf") {
      fileType = "pdf";
    }
    //img
    if (extra === "jpg" || extra === "png" || extra === "jpeg") {
      fileType = "img";
    }
    // 其他
    else {
      fileType = "other";
    }
  }

  /** @description 不显示没有文件类型的 */
  if (fileType === "none") {
    return undefined;
  }
  const previewFile = (url) => {
    Taro.downloadFile({
      url: url,
      success: function (res) {
        var filePath = res.tempFilePath;
        Taro.openDocument({
          filePath: filePath,
          success: function () {
            console.log("打开文档成功");
          },
        });
      },
    });
  };

  return (
    <View className="attachmentItem">
      <Flex align="center" justify="space-between">
        <View className="itemTitle">
          <Image
            className="fileIcon"
            src={fileType === "img" ? imageIcon : file}
          ></Image>
          {label}
        </View>

        {fileType === "pdf" && (
          <View
            className="fileView"
            onClick={() => {
              previewFile(composeImgUrl(value));
            }}
          >
            <View>pdf</View>
          </View>
        )}

        {fileType === "other" && (
          <View
            className="fileView"
            onClick={() => {
              previewFile(composeImgUrl(value));
            }}
          >
            <EyeOutlined />
          </View>
        )}
        {fileType === "img" && (
          <Image
            onClick={() => {
              Taro.previewImage({
                current: composeImgUrl(value),
                urls: [composeImgUrl(value)],
              });
            }}
            style={{ borderRadius: 4, width: 32, height: 32 }}
            src={composeImgUrl(value)}
          ></Image>
        )}
      </Flex>
    </View>
  );
};

/** 附件列表 */
const Attachment = (props) => {
  const { configSource, data } = props;

  const hasAttachmentConfig = useMemo(() => {
    return (
      configSource?.matterContentList?.filter((v) => {
        return (
          v.componentType == "ImgUpload" || v.componentType == "FileUpload"
        );
      }) ?? []
    );
  }, [configSource]);

  const findValue = (key) => {
    const reportContents = data?.reportContents ?? [];
    return reportContents.find((v) => v.contentId === key)?.content;
  };

  return (
    <View className="baseCard">
      <Space align="center">
        <DecoratePoint></DecoratePoint>
        <View className="baseCard_title">附件</View>
      </Space>
      <Toast id="toast"></Toast>
      {hasAttachmentConfig.length === 0 && (
        <Empty>
          <Empty.Description>无附件</Empty.Description>
        </Empty>
      )}
      {hasAttachmentConfig.map((item) => {
        return (
          <Item label={item.label} value={findValue(item.fieldKey)}></Item>
        );
      })}
    </View>
  );
};

export default Attachment;
