import { useMemo } from "react";
import DecoratePoint from "@/components/DecoratePoint";
import { Space } from "@taroify/core";
import { View } from "@tarojs/components";
import dayjs from "dayjs";

const Content = (props) => {
  const { configSource, data } = props;

  const config = useMemo(() => {
    const matterContentList = configSource?.matterContentList;

    if (matterContentList) {
      const temp = matterContentList
        .sort((pre: any, cur: any) => pre.sort - cur.sort)
        .map((item: any) => {
          return {
            ...item,
            componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
            key: item.fieldKey,
          };
        });

      return temp.filter((item: any) => {
        return (
          item.componentType !== "ImgUpload" &&
          item.componentType !== "FileUpload"
        );
      });
    }
    return [];
  }, [configSource]);

  const renderFormContentByType = (component: any, value?: any) => {
    const key = component.key;
    const reportContents = data?.reportContents ?? [];

    const contentValue =
      value ?? reportContents.find((v: any) => v.contentId === key)?.content;
   if(!contentValue){
     return
   }
    switch (component.componentType) {
      case "TextInput":
        return (
          <View>
            {(component.componentOption.prefix ?? "") +
              contentValue +
              (component.componentOption.suffix ?? "")}
          </View>
        );
      case "DatePicker":
        return (
          <View>
            {dayjs(contentValue).format(
              component.componentOption.picker === "time"
                ? "HH:mm"
                : component.componentOption.picker === "date"
                ? "YYYY-MM-DD"
                : "YYYY-MM"
            )}
          </View>
        );
      case "Branch": {
        return (
          <View>
            {contentValue?.map((item: any, i: number) => {
              return (
                <View>
                  <View>{component?.label + (i + 1)}</View>
                  <View></View>
                  {component.componentOption.children?.map((child) => {
                    return (
                      <Space>
                        <View>{child.label}：</View>

                        {
                          //@ts-ignore
                          renderFormContentByType(child, item[child.key])
                        }
                      </Space>
                    );
                  })}
                </View>
              );
            })}
          </View>
        );
      }
      default:
        return <View>{contentValue}</View>;
    }
  };

  return (
    <View className="baseCard">
      <Space align="center">
        <DecoratePoint></DecoratePoint>
        <View className="baseCard_title">申请内容</View>
      </Space>
      {config.map((v) => {
        return (
          <View key={v.key}>
            <Space>
              <View className="applyName">{v.label}：</View>
              <View className="applyValue">{renderFormContentByType(v) ?? '无'}</View>
            </Space>
          </View>
        );
      })}
    </View>
  );
};

export default Content;
