import { View } from "@tarojs/components";
import DecoratePoint from "@/components/DecoratePoint";
import { useEffect, useState } from "react";
import { composeImgUrl } from "@/utils/index";
import { Timeline, Image, Flex, Space, Button } from "@taroify/core";
import services from "@/services";
import Taro from "@tarojs/taro";
import { EyeOutlined } from "@taroify/icons";

const ProcessTimeLine = (props) => {
    const { detail } = props;

    const [dataSource, setDataSource] = useState<any[]>([]);

    const getData = () => {
        if (detail?.id) {
            services.report.getExamineHistory(detail.id).then((res: any) => {
                if (res.code === 200) {
                    setDataSource(res.data);
                }
            });
        }
    };
    const previewFile = (url) => {
        Taro.downloadFile({
            url: url,
            success: function (res) {
                var filePath = res.tempFilePath;
                Taro.openDocument({
                    filePath: filePath,
                    success: function () {
                        console.log("打开文档成功");
                    },
                });
            },
        });
    };

    useEffect(() => {
        getData();
    }, [detail]);

    console.log(dataSource);
    return <View className="baseCard">
        <Space align="center">
            <DecoratePoint></DecoratePoint>
            <View className="baseCard_title">审批流程</View>
        </Space>
        <Timeline position="right">
            {dataSource.map((v) => {
                let status = false;

                if (v.current) {
                    status = true;
                }
                if (v.approveTime) {
                    status = true;
                }
                const attachments = v.attachments;
                return <Timeline.Item>
                    <Timeline.Content direction="column" align="start">
                        <View style={{ width: "100%" }}>
                            <View className="title">
                                {v.nodeName + " " + (v?.approveUserName ?? "")}
                            </View>
                            <View className="time">{v.approveTime}</View>
                            {v.current && (
                                <Flex
                                    className="remake"
                                    align="center"
                                    justify="space-between"
                                >
                                    <View style={{ color: "rgba(1, 179, 110, 1)" }}>
                                        审批中...
                                    </View>
                                </Flex>
                            )}
                            {v?.approveComment && v.approveComment?.length > 0 && (
                                <View className="remake">
                                    <View>{v.approveComment}</View>
                                    <View className="attachment">
                                        {attachments?.map((attachment) => {
                                            let fileType = "none";
                                            if (attachment && attachment.length > 0) {
                                                const strList = attachment?.split(".") ?? [];
                                                const extra = strList[strList.length - 1];
                                                if (extra === "pdf") {
                                                    fileType = "pdf";
                                                }
                                                //img
                                                if (
                                                    extra === "jpg" ||
                                                    extra === "png" ||
                                                    extra === "jpeg"
                                                ) {
                                                    fileType = "img";
                                                }
                                                // 其他
                                                else {
                                                    fileType = "other";
                                                }
                                            }
                                            return (
                                                <>
                                                    {fileType === "pdf" && (
                                                        <View
                                                            className="fileView"
                                                            onClick={() => {
                                                                previewFile(composeImgUrl(attachment));
                                                            }}
                                                        >
                                                            pdf
                                                        </View>
                                                    )}
                                                    {fileType === "other" && (
                                                        <View
                                                            className="fileView"
                                                            onClick={() => {
                                                                previewFile(composeImgUrl(attachment));
                                                            }}
                                                        >
                                                            <EyeOutlined />
                                                        </View>
                                                    )}
                                                    {fileType === "img" && (
                                                        <Image
                                                            //   width={40}
                                                            //   height={40}
                                                            style={{ width: 40, height: 40, borderRadius: 4 }}
                                                            onClick={() => {
                                                                Taro.previewImage({
                                                                    current: composeImgUrl(attachment),
                                                                    urls: [composeImgUrl(attachment)],
                                                                });
                                                            }}
                                                            src={composeImgUrl(attachment)}
                                                        ></Image>
                                                    )}
                                                </>
                                            );
                                        })}
                                    </View>
                                </View>
                            )}
                        </View>
                    </Timeline.Content>
                </Timeline.Item>
            })}
        </Timeline>
        {dataSource.at(-1)?.approveStatus.value === 0 && <Button
            shape='round'
            block
            size='small'
            color='primary'
            style={{ margin: '10px auto 0' }}
            onClick={() => {
                Taro.navigateTo({ url: '/pages/Approve/Apply/index?anewSubmit=1' })
            }}>
            重新申请
        </Button>}
    </View>
};

export default ProcessTimeLine;
