import { useEffect, useState } from "react";
import Taro from "@tarojs/taro";
import { Flex, Tag } from "@taroify/core";
import Content from "./components/content";
import useGlobalStore from "@/store/useUserStore";
import bg from "@/assets/report/bg/bg1.png";
import Attachment from "./components/attachment";
import ProcessTimeLine from "./components/timeLine";
import services from "@/services";
import LabelText from "./components/labelText";
import "./index.css";
import { View, ScrollView, Text, Image } from "@tarojs/components";

const Detail = () => {
    const { actionObj, updateConfigSource } = useGlobalStore();

    const [configSource, setConfigSource] = useState({});
    const [detail, setDetail] = useState({});
    const routerParams = Taro.getCurrentInstance().router?.params;

    const init = () => {
        services.report.applyRecordDetail(actionObj.id).then((res: any) => {
            if (res.code === 200) {
                setDetail(res.data);
            }
        });

        services.report.getTemplateConfig(actionObj.thingId).then((res: any) => {
            if (res.code === 200) {
                setConfigSource(res.data);
            }
        });
    };

    useEffect(() => {
        init();
    }, [actionObj]);

    const goManage = () => {
        updateConfigSource(configSource);
        Taro.navigateTo({
            url: "/pages/manage/index",
        });
    };
    return (
        <View className="container">
            {/* <PageMeta>
                <NavigationBar
                    title="办理详情"
                    backgroundColor="#2E6CFF"
                    frontColor="#ffffff"
                    style={{ fontSize: 33 }}
                ></NavigationBar>
            </PageMeta> */}
            <ScrollView
                scrollY
                style={{
                    height:
                        Number(routerParams?.activeTab) != 1
                            ? "calc(100vh - 100px)"
                            : "calc(100vh - 30px)",
                }}
            >
                <View className="scrollArea">
                    <View className="topCard">
                        <Flex align="center">
                            <Text style={{ color: "#fff" }}>
                                {actionObj?.subjectName}-{actionObj?.name}
                            </Text>
                            <Tag style={{ whiteSpace: 'nowrap' }} color="success">{actionObj?.caseStatus?.name}</Tag>
                        </Flex>
                        <LabelText
                            label="组织机构代码"
                            text={actionObj?.subjectCode}
                        />
                        <LabelText
                            label="单位登记地址"
                            text={actionObj?.subjectAddress}
                        />
                        <LabelText
                            label="联系人"
                            text={actionObj?.subjectContact}
                        />
                        <LabelText
                            label="联系电话"
                            text={actionObj?.subjectPhone}
                        />
                        <Image src={bg} className="topCardImg"></Image>
                    </View>
                    <View>
                        <Content configSource={configSource} data={detail}></Content>
                    </View>
                    <View>
                        <Attachment configSource={configSource} data={detail}></Attachment>
                    </View>
                    <View>
                        <ProcessTimeLine detail={detail} />
                    </View>
                </View>
            </ScrollView>
            {Number(routerParams?.activeTab) != 1 ? (
                <View className="actionWrapper">
                    <View className="okBtn" onClick={goManage}>
                        去审批
                    </View>
                </View>
            ) : undefined}
        </View>
    );
};

export default Detail;
