import { Image, View, Text } from "@tarojs/components";
import "./index.less";

import Taro, { useDidShow } from "@tarojs/taro";
import services from "@/services";
import { useState } from "react";
import { composeImgUrl } from "@/utils";
import useArticleStore from "@/store/article";
import baseBg from '@/assets/bg/baseBg.png'
const ListItem = ({
  data,
  onClick,
}: {
  data: API.LawDto;
  onClick: () => void;
}) => (
  <View className="list-item" onTap={onClick}>
    <View>
      <Image
        src={data.coverImage ?  composeImgUrl(data.coverImage) : baseBg}
        mode="aspectFill"
        className="list-img"
      ></Image>
    </View>
    <View>
      <View className="list-title">{data.title}</View>
      <Text className="list-content">{data.digestText}</Text>
      <View className="time">{data.createTime}</View>
    </View>
  </View>
);

export default function () {
  const [dataSource, setDataSource] = useState<API.LawDto[]>([]);
  const { update } = useArticleStore();
  useDidShow(() => {
    services.common.getPolicyList().then((res) => {
      if (res.code === 200) {
        setDataSource(res.data);
      }
    });
  });

  const onClick = (item: API.LawDto) => {
    const content = {
      title: item.title,
      content: item.description,
      createTime: item.createTime,
    };
    update(content);
    Taro.navigateTo({
      url: "/pages/Article/index",
    });
  };

  return (
    <View className="law-container">
      {dataSource.map((item) => {
        return (
          <ListItem
            onClick={onClick.bind(this, item)}
            key={item.id}
            data={item}
          />
        );
      })}
    </View>
  );
}
