import { CSSProperties, FC, PropsWithChildren, useRef, useState } from "react";
import "./index.less";
import {
  View,
  Form,
  Input,
  Text,
  Button,
  Picker,
  Image,
} from "@tarojs/components";
import Container from "@/components/Container";
import joinIcon from "@/assets/images/kitchenWaste/join.svg";
import Taro, { useDidShow, useLoad } from "@tarojs/taro";
import globalStore from "@/store";
import api from "@/services";
import { useSetState } from "ahooks";
import dayjs from "dayjs";
import { getSubjectDetail } from "@/services/kitchenWaste";
import { getUrlParams } from "@/utils/comm";
import useGlobalStore from "@/store";

interface FormItemProps {
  style?: CSSProperties;
  label: string;
}
export const FormItem: FC<PropsWithChildren<FormItemProps>> = ({
  children,
  style,
  label,
}) => {
  return (
    <View style={style}>
      <View className="form-item">
        <Text>{label}</Text>
      </View>
      {children}
    </View>
  );
};
/**
 * @description 收运记录
 */
const Record: FC = () => {
  const {userInfo,updateUserInfo,mainBodyInfo,queryMainBodyInfo} = useGlobalStore()
  const { businessId } = Taro.getCurrentInstance().router?.params || {};
  const [selectedIds, setSelectedIds] = useSetState<{
    k1?: any;
    k2?: any;
  }>({});
  const [selectedDate, setSelectedDate] = useSetState<{
    date: string;
    time: string;
  }>({
    date: dayjs().format("YYYY-MM-DD hh:mm:ss"),
    time: dayjs().format("HH:mm"),
  });
  const [vehicles, setVehicles] = useState<API.CarListDot[]>([]);
  const [signEntities, setSignEntities] = useState<API.MerchantsListDot[]>([]);
  const { collectionInfo } = globalStore();

  useDidShow(() => {
    // api.kitchenWaste.queryCarList().then((res) => {
    //   if (res.code === 200) {
    //     setVehicles(res.data);
    //   }
    // });

    // getSignMerchant()
  });

  const getSignMerchant = ()=>{
    api.kitchenWaste.getSignEntities().then((res) => {
      if (res.code === 200) {
        const data = res.data
        if(defaultId.current){
            getDetail(defaultId.current,data)
        }else {
            setSignEntities(data);
            if(data.length !== 0){
                let index = data?.findIndex((v) => v.value === businessId);
                setSelectedIds({
                    k1: index !== -1 ? index.toString() : '0',
                });
            }
        }
      }else {
        Taro.showToast({title:res.msg || '',icon:'none'})
      }
    });
  }

  //提交表单
  const formSubmit = (e) => {
    let { value } = e.target;
    for (let i in value) {
      if (!value[i]) {
        Taro.showToast({
          title: "请填写完整数据后再提交！",
          icon: "error",
          duration: 2000,
        });
        return;
      }
    }
    if(!mainBodyInfo){
        Taro.showToast({title:'未认证公司！',icon:'none',mask:true})
        return
    }
    const { collectionDate, ...reset } = value;
    let params = {
      ...reset,
    //   carNum: vehicles[value.carNum].label,
      businessName: signEntities[value.businessName].name,
      businessId: signEntities[value.businessName].value,
      collectionId: mainBodyInfo[0]?.id,
      collectionName: mainBodyInfo[0]?.name,
      collectionTime: selectedDate.date,
      personnelName:userInfo?.nickname
    };
    api.kitchenWaste.submitForWl(params).then((res) => {
      if (res.code === 200) {
        Taro.showToast({
          title: "提交成功",
          icon: "success",
          duration: 2000,
          mask: true,
          success: () => {
            setTimeout(() => {
                Taro.redirectTo({url:'/pages/kitchenWaste/index'})
            }, 800);
          },
        });
      } else {
        Taro.showToast({
          title: res.msg ?? "",
          icon: "error",
          duration: 2000,
        });
      }
    });
  };

  const defaultId = useRef<string>('')
  const getDetail = async (id:string,arr:any[])=>{
    const index = arr.findIndex(v=>v.value === id)
    if(index === -1){
        const res = await getSubjectDetail(id)
        if(res.code === 200){
            const {label:name,value} = res.data
            setSignEntities([{name,value},...arr])
            setSelectedIds({k1:0})
        }else {
            setSignEntities(arr)
        }
    }else {
        setSignEntities(arr)
        setSelectedIds({k1:index})
    }
  }

  useLoad((options)=>{
    console.log(mainBodyInfo);
    // options.merchantId = '0019a1293be6bb59cb02aa937624e718'
    const token = Taro.getStorageSync('token')
    if(token){
        if(options.merchantId){
            defaultId.current =options.merchantId
        }
        if(options.q){
            console.log(options);
            const url = decodeURIComponent(options.q)
            const {merchantId} = getUrlParams(url) as any
            defaultId.current = merchantId
        }
        if(userInfo){
            getSignMerchant()
        }else {
            updateUserInfo().then((userInfo)=>{
                if(userInfo){
                    queryMainBodyInfo().then((data)=>{
                        if(data && data.length !== 0){
                            getSignMerchant()
                        }
                    })
                }
            })
        }
    }else {
        Taro.showToast({title:'用户登录过期，请重新登录',icon:'none',mask:true})
        setTimeout(()=>{
            Taro.redirectTo({url:'/pages/Index/index'})
        },1000)
    }
  })

  return (
    <Container title="电子五联单" style={{ backgroundColor: "#EEF7EF" }}>
      <View className="main">
        <Form onSubmit={formSubmit}>
          <FormItem label="产生单位">
            <Picker
              name="businessName"
              mode="selector"
              rangeKey="name"
              value={selectedIds.k1}
              range={signEntities}
              onChange={(e: any) => {
                setSelectedIds({ k1: e.detail.value });
              }}
            >
              <View className="form-input">
                {selectedIds.k1 !== undefined ? (
                  signEntities[selectedIds.k1].name
                ) : (
                  <Text className="placeholder">请选择单位</Text>
                )}
                <View className="select-text">
                  请选择 <Image src={joinIcon} />
                </View>
              </View>
            </Picker>
          </FormItem>
          {/* <FormItem label="收运单位" style={{ marginTop: 29 }}>
            <Input
              name="collectionName"
              defaultValue={collectionInfo?.name ?? ""}
              className="form-input"
              placeholder="输入收运单位"
            />
          </FormItem> */}
          <FormItem label="收运重量（公斤）" style={{ marginTop: 29 }}>
            <Input
              type="digit"
              name="weight"
              className="form-input"
              placeholder="输入收运重量（公斤）"
            />
          </FormItem>
          <FormItem label="收运信息" style={{ marginTop: 29 }}>
            <View className="syBox">
                <View>
                    <Text>收运公司：</Text>
                    {mainBodyInfo && mainBodyInfo[0].name}
                </View>
                <View>
                    <Text>收运时间：</Text>
                    {selectedDate.date}
                </View>
                <View>
                    <Text>收运人：</Text>
                    {userInfo?.nickname}
                </View>
            </View>
          </FormItem>

          {/* <FormItem label="收运人" style={{ marginTop: 29 }}>
            <Input
              name="personnelName"
              className="form-input"
              placeholder="输入收运人"
            />
          </FormItem>
          <FormItem label="车辆" style={{ marginTop: 29 }}>
            <Picker
              name="carNum"
              mode="selector"
              rangeKey="label"
              range={vehicles}
              onChange={(e: any) => {
                setSelectedIds({ k2: e.detail.value });
              }}
            >
              <View className="form-input">
                {selectedIds.k2 ? (
                  vehicles[selectedIds.k2].label
                ) : (
                  <Text className="placeholder">请选择车辆</Text>
                )}
                <View className="select-text">
                  请选择 <Image src={joinIcon} />
                </View>
              </View>
            </Picker>
          </FormItem>
          <FormItem label="收运日期" style={{ marginTop: 29 }}>
            <Picker
              name="collectionDate"
              mode="date"
              value={selectedDate.date}
              onChange={(e) => {
                setSelectedDate({ date: e.detail.value });
              }}
            >
              <View className="form-input">
                {selectedDate.date || (
                  <Text className="placeholder">请选择收运日期</Text>
                )}
                <View className="select-text">
                  请选择 <Image src={joinIcon} />
                </View>
              </View>
            </Picker>
          </FormItem>
          <FormItem label="收运时间" style={{ marginTop: 29 }}>
            <Picker
              name="collectionTime"
              mode="time"
              value={selectedDate.time}
              onChange={(e) => {
                setSelectedDate({ time: e.detail.value });
              }}
            >
              <View className="form-input">
                {selectedDate.time || (
                  <Text className="placeholder">请选择收运时间</Text>
                )}
                <View className="select-text">
                  请选择 <Image src={joinIcon} />
                </View>
              </View>
            </Picker>
          </FormItem> */}

          <Button formType="submit" className="sub-btn" plain>
            <Text>提交</Text>
          </Button>
        </Form>
      </View>
    </Container>
  );
};
export default Record;
