import { View, Camera, Icon, Text, Image } from "@tarojs/components";
import _ from "lodash";
import { Button } from "@nutui/nutui-react-taro";
import { useEffect, useMemo, useRef, useState } from "react";
import Taro, { useDidShow, useLoad, useUnload } from "@tarojs/taro";
import api from "@/services/core/api";
import "./cameraComp.less";
import useReportStore from "@/store/report";
import { getAuth, queryParams } from "@/utils/comm";
import region from "@/assets/images/region.png"
import photoBtn from "@/assets/images/photoBtn.png"
import ZoomView from "@/components/ZoomView/ZoomView";
import RotatingCanvas, {
  RotatingCanvasRef,
} from "@/components/RotatingCanvas/RotatingCanvas";
import compressImg from "@/utils/compressImg";
import { closeForRenewal, specialProject } from "@/services/kitchenWaste";
interface ImgPathDto {
  type: 1 | 2 | 3;
  path: string;
}
//举手之劳
const liftFingerImgConfig = [
  {
    text: "处置前",
    type: 1.1,
  },
  {
    text: "处置后",
    type: 1.2,
  },
];

//拍照图片集
const commImgConfig = [
  {
    text: "近景",
    type: 2,
  },
  {
    text: "远景",
    type: 0.5,
  },
  {
    text: "其他",
    type: 1,
  },
];

function CameraComp() {
  // const { reportStore } = reportStore; //上报事件全局数据
  const { discoverEntry, discoverEntryName ,eventReportInfoExtend} = useReportStore(); //巡查入口
  const pathDefault: ImgPathDto[] = [
    {
      type: 1,
      path: "",
    },
    {
      type: 2,
      path: "",
    },
    {
      type: 3,
      path: "",
    },
  ];
  const ctx = Taro.createCameraContext();
  //设置选中图片的标识
  const [zoom, setZoom] = useState(() => {
    return discoverEntry === "liftFinger" ? 1.1 : 2;
  });
  const [imgPath, setImgPath] = useState<ImgPathDto[]>(pathDefault);

  //附件图片
  const attmentPreUrlList = useRef<ImgPathDto[]>(pathDefault);
  useDidShow(() => {
    getAuth("scope.camera", "请打开相机权限", () => {
      Taro.navigateBack();
    });
  });
  useEffect(() => {
    ctx.setZoom({
      zoom,
    });
  }, [zoom]);

  const rotateRef = useRef<RotatingCanvasRef>(null);
  const deviceType = useRef("");
  //拍照
  const takePhoto = async () => {
    ctx.takePhoto({
      quality: "high",
      success: async ({ tempImagePath }) => {
        // const { tempFiles: [tempImagePath] } = await Taro.chooseMedia({ mediaType: ['image'] })
        // const { tempFilePath } = tempImagePath

        const screenDirection = screenStatus.current;
        const { filePath: path } = await compressImg.set(tempImagePath, 2048);
        let filePath = path;
        if (screenDirection === "1") {
          console.log("逆时针旋转");
          const angle = deviceType.current === "ios" ? 90 : -90;
          filePath = await rotateRef.current?.rotateImage(filePath, angle)!;
        } else if (screenDirection === "2") {
          console.log("顺时针旋转");
          const angle = deviceType.current === "ios" ? -90 : 90;
          filePath = await rotateRef.current?.rotateImage(filePath, angle)!;
        }

        //上传图片
        Taro.showLoading({ title: "正在上传", mask: true });
        console.log("文件上传：", api.uploadUrl);
        Taro.uploadFile({
          url: api.uploadUrl,
          filePath,
          header: { authorization: "Bearer " + Taro.getStorageSync("token") },
          name: "file",
          success(imgRes) {
            if (imgRes.statusCode === 200) {
              const imgResultReq = JSON.parse(imgRes.data);
              console.log("文件上传响应：", imgResultReq);
              const attmentImg = api.assetsUrl + imgResultReq.data;
              console.log(attmentImg);

              //焦距缩放配置
              const zoomConfig =
                discoverEntry === "liftFinger" ? [1.1, 1.2] : [2, 0.5, 1];
              const pathList = _.cloneDeep(imgPath);
              const zoomIndex = zoomConfig.findIndex((it) => it === zoom); //当前zoom的索引
              pathList[zoomIndex].path = filePath;
              attmentPreUrlList.current[zoomIndex].path = attmentImg;
              const nextZoom = zoomConfig[zoomIndex > 1 ? 2 : zoomIndex + 1]; //下个zoom

              setZoom(nextZoom);
              setImgPath(pathList);
              Taro.hideLoading();
            } else {
              Taro.showToast({
                title: "文件上传失败，请重新上传",
                icon: "none",
                mask: true,
              });
            }
          },
          fail: () => {
            Taro.showToast({
              title: "文件上传失败，请重新上传",
              icon: "none",
              mask: true,
            });
          },
        });
      },
    });
  };
  //设置缩放级别
  const setScaleZoom = (zoom: number) => {
    setZoom(zoom);
  };
  //删除图片
  const handleClearImg = (index: number) => {
    let pathList = _.cloneDeep(imgPath);
    pathList[index].path = "";
    setImgPath(pathList);
  };
  const showNextBtn = () => {
    const arr = imgPath.filter((it) => it.path.length > 1);
    if (discoverEntry === "closePhoto") {
      return arr.length >= 1;
    }
    return arr.length > 1;
  };
console.log(imgPath);

  //下一步，拿第一张照片去获取类别
  const handleNextPage = async () => {
    let fileimgList = attmentPreUrlList.current?.map((it) => it.path);
    if (discoverEntry === "closePhoto") {
      const res = await closeForRenewal({
        entitieId: discoverEntryName,
        photos: fileimgList[0],
      });
      if (res.code === 200) {
        Taro.showToast({ title: "操作成功", icon: "none", mask: true });
        setTimeout(() => {
          Taro.navigateBack();
        }, 1000);
      }
      return;
    }
   

  };

  //上传图片配置
  const cameraImgConfig = useMemo(() => {
    if (discoverEntry === "closePhoto") {
      return [{ text: "关店照", type: 1 }];
    }
    return discoverEntry === "liftFinger" ? liftFingerImgConfig : commImgConfig;
  }, []);

  const screenStatus = useRef("0");
  useLoad(() => {
    compressImg.clearTempImg();
    Taro.getSystemInfo({
      success: ({ platform }) => {
        deviceType.current = platform;
      },
    });
    Taro.startDeviceMotionListening({
      interval: "normal",
      success: () => {
        Taro.onDeviceMotionChange(({ beta, gamma }) => {
          screenStatus.current = "0";
          if (Math.abs(beta) < 45 && Math.abs(gamma - 90) < 45) {
            screenStatus.current = "1";
          } else if (Math.abs(beta) < 45 && Math.abs(gamma + 90) < 45) {
            screenStatus.current = "2";
          }
        });
      },
    });
  });

  useUnload(() => {
    Taro.offDeviceMotionChange();
    compressImg.clearTempImg();
  });

  return (
    <View className="wrap">
      <Camera
        outputDimension="1080P"
        device-position="back"
        flash="off"
        style="width: 100%; height: 100%"
      />
      <ZoomView
        width="100vw"
        height="100vh"
        zIndex={998}
        onZoom={(zoom) => {
          ctx.setZoom({ zoom });
        }}
      />
      <RotatingCanvas ref={rotateRef} />
      <Image
        className="region-icon"
        src={region}
      />
      <View className="footer">
        <View className="img-wrap dflex">
          {/* 举手之劳显示处置前和处置后的图片，其他拍照显示近/远/其他，逻辑不变 */}
          {cameraImgConfig?.map((it, index) => (
            <View
              key={it.type}
              className={
                zoom === it.type ? "img-box active" : "img-box imgpre-box"
              }
              onClick={() => setScaleZoom(it.type)}
            >
              <Text className="text"> {it.text}</Text>
              {imgPath[index]?.path && (
                <>
                  <Icon
                    size={18}
                    type="clear"
                    className="clear-icon"
                    color="red"
                    onClick={() => handleClearImg(index)}
                  />
                  <View className="thumb-wrap">
                    <Image src={imgPath[index].path} className="img-thumb" />
                  </View>
                </>
              )}
            </View>
          ))}
        </View>

        <Image
          onClick={takePhoto}
          className="photo-icon"
          src={photoBtn}
        />

        <Button
          type="info"
          className="next-btn"
          style={{
            opacity: showNextBtn() ? 1 : 0,
          }}
          onClick={handleNextPage}
        >
          下一步
        </Button>
      </View>
    </View>
  );
}

export default CameraComp;
