import Taro, { useDidShow, useLoad, useRouter } from "@tarojs/taro";
import styles from "./shopList.module.less";
import { Input, ScrollView, Text, Image, View } from "@tarojs/components";
import { Search } from "@nutui/icons-react-taro";
import Flex from "@/components/Flex/Flex";
import map from "@/assets/images/event/map.png";
import { useCallback, useRef, useState } from "react";
import { nearbyBusinessesPageList } from "@/services/kitchenWaste";
import useMapLocation from "@/hooks/useMapLocation";
import { wgs84ToBd09 } from "@/utils/coordinateTransformation";
import api from "@/services/core/api";
import { debounce } from "lodash";
import { Button, Empty, Popup } from "@nutui/nutui-react-taro";
import paizhao from "@/assets/images/paizhao.png";
import useReportStore from "@/store/report";
import { queryParams } from "@/utils/comm";
import emptyImg from "@/assets/images/empty2.png";
import Container from "@/components/Container";
import emptyImg1 from "@/assets/images/empty.png";
const ShopList = () => {
  const {
    params: { title, entityType },
  } = useRouter();
  const { updateDiscover } = useReportStore();
  const { getLocationAndAddress } = useMapLocation();
  const searchText = useRef("");

  // const locations = useRef({ latitude: 30.891552545223195, longitude: 104.00907261600372 })
  const lo = useRef({ latitude: 0, longitude: 0 });
  const page = useRef(1);
  const [list, setList] = useState<any[]>([]);
  const [total, setTotal] = useState(0);
  const getList = async () => {
    const query = {
      page: page.current,
      count: 10,
      // entityType: '0bc46fb4-a3c5-11ee-b5a6-0242ac120005',
      entityType,
      searchText: searchText.current,
      ...lo.current,
    };
    const res = await nearbyBusinessesPageList(query);
    if (res.code === 200) {
      const lists = res.data.items;
      if (page.current === 1) {
        setList(lists);
      } else {
        setList([...list, ...res.data.items]);
      }
      setTotal(Number(res.data.total));
    }
  };
  useDidShow(() => {
    if (lo.current.latitude !== 0) {
      page.current = 1;
      setList([]);
      getList();
    }
  });

  useLoad(async () => {
    const { lon, lat } = await getLocationAndAddress();
    const { longitude, latitude } = wgs84ToBd09(lon, lat);
    lo.current = { longitude, latitude };
    page.current = 1;
    setList([]);
    getList();
  });

  const getList2 = useCallback(
    debounce(
      () => {
        page.current = 1;
        getList();
      },
      500,
      {}
    ),
    []
  );

  const [activeIndex, setActiveIndex] = useState(0);
  const [closeShow, setCloseShow] = useState(false);

  return (
    <Container title={title} style={{padding:10}}>
      <Flex className={styles.inpBox} align="center">
        <Input
          className={styles.inp}
          placeholder="请输入门头名称搜索"
          onInput={(e) => {
            searchText.current = e.detail.value;
            getList2();
          }}
        />
        <Search color="#3E6BDA" />
      </Flex>
      {list.length === 0 && (
        <Empty
          style={{ backgroundColor: "transparent" }}
          title=" "
          description="附近一公里没有店铺"
          image={<img src={emptyImg1} />}
        />
      )}

      <ScrollView
        style={{ height: "calc(100vh - 50px - 85PX)" }}
        scrollY
        onScrollToLower={() => {
          if (list.length >= total) {
            Taro.showToast({ title: "没有更多了", mask: true, icon: "none" });
            return;
          }
          page.current += 1;
          getList();
        }}
      >
        {list.map((v, i) => {
          const {
            id,
            attachmentList,
            name,
            address,
            distanceMeters,
            entityTypeId,
            entityTypeName,
            unifiedSocialCreditCode,
          } = v;
          const imgUrl = attachmentList
            ? api.assetsUrl + attachmentList[0]?.pictures[0]
            : "";

          return (
            <Flex
              className={styles.listItem}
              key={i}
              vertical
              align="center"
              onClick={() => {
                if (title === "店铺更新") {
                  console.log(v);
                  const query = {
                    creditCode: unifiedSocialCreditCode,
                    entityTypeId,
                    entityTypeName,
                    id,
                  };
                  Taro.navigateTo({
                    url:
                      "/pages/kitchenWaste/pages/shopPerfectInfo/shopPerfectInfo" +
                      queryParams(query),
                  });
                } else {
                  setActiveIndex(i);
                  setCloseShow(true);
                }
              }}
            >
              <Image
                className={styles.img}
                src={imgUrl || emptyImg}
                mode="heightFix"
              />
              <Flex
                className={styles.bottom}
                flex={1}
                vertical
                justify="space-between"
              >
                <Flex justify="space-between">
                  <Text className={styles.title}>{name}</Text>
                  {/* <Text className={styles.distance}>&lt; {distanceMeters}米</Text> */}
                  <Text className={styles.distance}>{distanceMeters}米</Text>
                </Flex>
                <Flex className={styles.shopAddress} align="center" gap={10}>
                  <Image src={map} />
                  {address}
                </Flex>
              </Flex>
            </Flex>
          );
        })}
      </ScrollView>
      <Popup
        visible={closeShow}
        onClose={() => setCloseShow(false)}
        className={styles.closePopup}
      >
        <Flex vertical justify="space-between" style={{ height: "100%" }}>
          <View className={styles.title}>确认</View>
          <View className={styles.content}>
            确认{list[activeIndex]?.name}已经关闭？
          </View>
          <Flex className={styles.btnBox} justify="space-between">
            <Button
              className={styles.cancel}
              onClick={() => setCloseShow(false)}
            >
              取消
            </Button>
            <Button
              className={styles.shopconfirm}
              icon={<Image style={{ width: 20, height: 17 }} src={paizhao} />}
              onClick={() => {
                setCloseShow(false);
                updateDiscover("closePhoto", list[activeIndex].id);
                Taro.navigateTo({
                  url: "/pages/kitchenWaste/pages/cameraComp/cameraComp",
                });
              }}
            >
              去拍一张关店照
            </Button>
          </Flex>
        </Flex>
      </Popup>
    </Container>
  );
};

export default ShopList;
