import {
  Button,
  DatePicker,
  Form,
  Input,
  Uploader,
} from "@nutui/nutui-react-taro";
import Taro, { useDidShow, useLoad, useRouter } from "@tarojs/taro";
import styles from "./shopPerfectInfo.module.less";
import { useState } from "react";
import Flex from "@/components/Flex/Flex";
import { View, Image } from "@tarojs/components";
// import useMapLocation from "@/hooks/useMapLocation";
import { getAuth } from "@/utils/comm";
import { wgs84ToBd09 } from "@/utils/coordinateTransformation";
import dayjs from "dayjs";

import Container from "@/components/Container";
import api from "@/services/core/api";
import services from "@/services";
import address from "@/assets/images/address.png";
import AddressSelect from "@/components/AddressSelect/AddressSelect";
const headers = { authorization: "Bearer " + Taro.getStorageSync("token") };
const ShopPerfectInfo = () => {
  const {
    params: { id, creditCode, entityTypeId, entityTypeName },
  } = useRouter();
  const [form] = Form.useForm();
  const [locationShow, setLocationShow] = useState(false);

  const getDetail = async () => {
    const res = await services.kitchenWaste.postDetailEntites(id as string);
    if (res.code === 200) {
      const data = res.data;
      const attachmentList = data.attachmentList
        ? data.attachmentList.map((v) => {
            const { name, pictures } = v;
            const obj = {
              name,
              pictures: pictures
                ? pictures.map((item) => {
                    return {
                      type: "image",
                      uid: item,
                      name: item,
                      url: api.assetsUrl + item,
                      status: "success",
                      message: "success",
                    };
                  })
                : [],
            };
            return obj;
          })
        : [];

      data.tags && setTagsName(data.tags);
      setAttachmentList(attachmentList);
      data.attachment = data.attachmentList?.[0].pictures?.map((item) => ({
        type: "image",
        uid: item,
        name: item,
        url: api.assetsUrl + item,
        id: item,
        status: "success",
        message: "success",
      }));
      form.setFieldsValue(data);
    }
  };

  useLoad(() => {
    if (id) {
      getDetail();
    }
  });

  useDidShow(() => {
    getAuth("scope.userLocation", "请设置位置权限", () => {
      Taro.navigateBack();
    });
  });

  const [dateShow, setDateShow] = useState(false);

  const [tagsName, setTagsName] = useState<string[]>([]);
  // const { getLocationAndAddress } = useMapLocation();

  const [attachmentList, setAttachmentList] = useState<
    { pictures: any[]; name: string }[]
  >([]);

  return (
    <Container title="完善店铺信息" style={{ padding: 10 }}>
      <Form
        form={form}
        labelPosition="top"
        footer={
          <Button
            className={styles.btn}
            nativeType="submit"
            block
            type="primary"
          >
            提交
          </Button>
        }
        initialValues={{
          unifiedSocialCreditCode: creditCode,
          registerTime: dayjs().format("YYYY-MM-DD"),
        }}
        onFinish={async (values) => {
          values.businessStatus = 1;
          values.tagsList = tagsName;
          values.registerTime =
            dayjs(values.registerTime).format("YYYY-MM-DD") + " 00:00:00";

          values.attachmentList = values?.attachment
            ? [
                {
                  name: "店铺图片",
                  pictures: values?.attachment?.map((item) => item?.uid),
                },
              ]
            : undefined;
          values.entityTypeId = entityTypeId;
          values.entityTypeName = entityTypeName;
          values.infoSource = "XCT";
          delete values.tags;
          const res = await services.kitchenWaste.postSaveOrUpdateEntites(
            values
          );
          if (res.code === 200) {
            Taro.navigateBack();
          }
        }}
      >
        <Form.Item
          label="门头名称"
          name="alias"
          rules={[{ required: true, message: "请输入" }]}
        >
          <Input className={styles.inp} placeholder="请输入" />
        </Form.Item>
        <Form.Item
          label="营业执照名称"
          name="name"
          rules={[{ required: true, message: "请输入" }]}
        >
          <Input className={styles.inp} placeholder="请输入" />
        </Form.Item>

        <Form.Item label="联系人" name="contactName">
          <Input className={styles.inp} placeholder="请输入" />
        </Form.Item>
        <Form.Item label="联系电话" name="phone">
          <Input className={styles.inp} placeholder="请输入" maxLength={11} />
        </Form.Item>
        <Form.Item
          label="企业类别"
          name="industry"
          rules={[{ required: true, message: "请输入" }]}
        >
          <Input className={styles.inp} placeholder="请输入" />
        </Form.Item>

        <Flex align="flex-end">
          <Form.Item label="位置" name="address">
            <Input
              className={styles.inp}
              placeholder="点击右侧选择位置"
              style={{ width: 272 }}
            />
          </Form.Item>
          <View style={{ paddingBottom: 10 }}>
            <Image
              src={address}
              style={{ width: 50, height: 50 }}
              onClick={() => {
                setLocationShow(true);
              }}
            />
          </View>
        </Flex>
        <Form.Item label="店铺图片" name="attachment">
          <Uploader
            style={{ marginTop: 15 }}
            url={api.uploadUrl}
            maxCount="3"
            headers={headers}
            onDelete={(file) => {
              const attachment = form.getFieldValue("attachment");
              const list = attachment.filter((v) => {
                return v.uid !== file.uid;
              });
              form.setFieldsValue({ attachment: list });
            }}
            onSuccess={(e) => {
              // @ts-ignore
              if (e.responseText.statusCode === 200) {
                // @ts-ignore
                const uploadRes = JSON.parse(e.responseText.data);
                if (uploadRes.code === 200) {
                  const attachment = form
                    .getFieldValue("attachment")
                    ?.filter((item) => !!item?.id);
                  console.log(attachment);

                  attachment.push({
                    url: api.assetsUrl + uploadRes.data,
                    status: "success",
                    type: "image",
                    name: uploadRes.data,
                    uid: uploadRes.data,
                    message: "正在上传",
                    id: uploadRes.data,
                  });
                  form.setFieldsValue({ attachment });
                }
              }
            }}
          />
        </Form.Item>
      </Form>
      <DatePicker
        title="日期选择"
        visible={dateShow}
        defaultValue={new Date()}
        showChinese
        onClose={() => setDateShow(false)}
        threeDimensional={false}
        onConfirm={(_, values) => {
          form.setFieldsValue({ registerTime: values.join("-") });
        }}
      />
      
        <AddressSelect
          show={locationShow}
          onConfirm={(addressInfo) => {
            const { lon, lat, address } = addressInfo;
            const { longitude, latitude } = wgs84ToBd09(
              Number(lon),
              Number(lat)
            );
            form.setFieldsValue({
              address,
              lon: longitude,
              lat: latitude,
            });
            setLocationShow(false);
          }}
          onCancale={() => {
            setLocationShow(false);
          }}
        />
      
    </Container>
  );
};

export default ShopPerfectInfo;
