import { View, Image } from '@tarojs/components'
import { Button, Flex, Input } from '@taroify/core'
import './login.less'
import icon39 from '@/assets/icon/icon39.png'
import icon40 from '@/assets/icon/icon40.png'
import { useState } from 'react'
import Taro from '@tarojs/taro'
import { encryption } from '@/utils/comm'
import { postLogin } from '@/services/loginController'
import useGlobalStore from '@/store'
import MyNavBar from '@/components/MyNavBar/MyNavBar'

const client_id = 'xindumange';
const client_secret = 'xindu@2024';
const Login = () => {
    const { updateUserInfo, queryAuthenticationInfo } = useGlobalStore();
    const [username, setUsername] = useState('')
    const [password, setPassword] = useState('')

    const toLogin = () => {
        if (!username) {
            Taro.showToast({ title: '请输入账号', mask: true, icon: 'none' })
            return
        }
        if (!password) {
            Taro.showToast({ title: '请输入密码', mask: true, icon: 'none' })
            return
        }
        const data = {
            username,
            password,
            randomStr: '',
            grant_type: 'password',
            scope: 'server'
        }
        data.password = encryption(data.password, 'thanks,hncycloud');
        postLogin(data, `${client_id}:${client_secret}`).then((res) => {
            if (res.code === 200) {
                Taro.setStorageSync("token", res.data.access_token);
                updateUserInfo();
                queryAuthenticationInfo();
                Taro.redirectTo({
                    url: '/pages/Index/index'
                })
            } else {
                Taro.showToast({ title: res.msg || '登录失败', icon: 'none', mask: true })
            }
        })
    }

    return <View className='box'>
        <MyNavBar background='transparency'/>
        <View className='loginBox'>
            <View className='inpItem'>
                <Flex className='txt' gutter={5}>
                    <Flex.Item>
                        <Image style={{ width: 20, height: 20 }} src={icon39} />
                    </Flex.Item>
                    <Flex.Item>账号</Flex.Item>
                </Flex>
                <Input className='inp' placeholder='请输入账号' maxlength={11} value={username} onChange={(e) => setUsername(e.detail.value)} />
            </View>
            <View className='inpItem'>
                <Flex className='txt' gutter={5}>
                    <Flex.Item>
                        <Image style={{ width: 20, height: 20 }} src={icon40} />
                    </Flex.Item>
                    <Flex.Item>密码</Flex.Item>
                </Flex>
                <Input className='inp' placeholder='请输入密码' value={password} onChange={(e) => setPassword(e.detail.value)} />
            </View>
            <Button className='btn' shape='round' block onClick={toLogin}>登录</Button>
        </View>
    </View>
}

export default Login