import api from "./core/api";
import request from "./core/request";

/**
 * @description: 首页-商户、签约、收运统计
 */
export async function queryStatisticsForWeChat(): Promise<
  Resp<API.StatisticsDto>
> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionContract/statisticsForWeChat",
    { method: "GET" }
  );
}

/**
 * @description: 首页-推荐产生单位
 */
export async function queryRecommendForWeChat(
  lat: number,
  lon: number
): Promise<Resp<API.RecommendDto[]>> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionRecord/recommendForWeChat",
    {
      method: "GET",
      data: {
        lat,
        lon,
      },
    }
  );
}

/**
 * @description: 首页-获取收运公司信息
 */
export async function getEntitieInfo(): Promise<Resp<any>> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionContract/getEntitieInfo",
    { method: "GET" }
  );
}

/**
 * @description: 电子五连-获取车辆
 */
export async function queryCarList(): Promise<Resp<API.CarListDot[]>> {
  return request(api.kitchenWasteUrl + "/wasteCollectionRecord/getCar", {
    method: "GET",
  });
}

/**
 * @description: 电子五连-提交
 */
export async function submitForWl(data: any): Promise<Resp<any>> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionRecord/addWasteCollectionRecord",
    {
      method: "POST",
      data,
    }
  );
}

/**
 * @description: 以签约商户列表
 */
export async function getSignListForWeChat(): Promise<Resp<API.SignListDto[]>> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionContract/getSignListForWeChat",
    {
      method: "GET",
    }
  );
}

/**
 * @description: 未签约商户下拉
 */
export async function getNotSignEntities(): Promise<
  Resp<API.MerchantsListDot[]>
> {
  return request(
    api.kitchenWasteUrl +
      "/wasteCollectionContract/getNotSignEntitiesForWeChat",
    {
      method: "GET",
    }
  );
}

/**
 * @description: 已经签约商户下拉
 */
export async function getSignEntities(): Promise<Resp<API.MerchantsListDot[]>> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionContract/getSignEntitiesForWeChat",
    {
      method: "GET",
    }
  );
}

/**
 * @description: 添加商户-提交
 */
export async function addWasteCollectionContract(
  data: any
): Promise<Resp<any>> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionContract/addWasteCollectionContract",
    {
      method: "POST",
      data,
    }
  );
}

/**
 * @description: 收运记录
 */
export async function getCollectionListForWeChat(): Promise<
  Resp<API.CollectionListDto[]>
> {
  return request(
    api.kitchenWasteUrl + "/wasteCollectionRecord/getCollectionListForWeChat",
    {
      method: "GET",
    }
  );
}

// 获取主体详情
export async function getSubjectDetail(id: string): Promise<Resp<any>> {
  return request(
    api.authenticationUrl + `/hncy/entities/getSubjectName/${id}`,
    {
      method: "GET",
    }
  );
}

// 百度地址逆解析
export async function baiduLocationAnalysis(
  lon: string | number,
  lat: string | number
): Promise<any> {
  return request(
    api.eventUrl + `/preprocessing/region-info/baiduReverseGeocoding`,
    {
      method: "POST",
      data: { lon, lat, coordinateSystem: "gcj02ll" },
      header: {
        "Content-Type": "application/x-www-form-urlencoded",
      },
    }
  );
}

export async function postDetailEntites(id: string): Promise<any> {
  return request(
    api.eventUrl + `/violating-subject/hncy/entities/queryDetail?id=${id}`,
    {
      method: "POST",
    }
  );
}

// 添加/编辑  主体信息
export async function postSaveOrUpdateEntites(data: any): Promise<any> {
  return request(
    api.eventUrl + `/violating-subject/hncy/entities/saveOrUpdateEntites`,
    {
      method: "POST",
      data,
    }
  );
}

// 查询附近的商户 /violating-subject

export async function nearbyBusinessesPageList(data: any): Promise<any> {
  return request(
    api.eventUrl + `/violating-subject/hncy/entities/nearbyEntitiesList`,
    {
      method: "POST",
      data,
      header: {
        'Content-Type': 'application/x-www-form-urlencoded'
    },
    }
  );
}
//关店店铺更新

export async function closeForRenewal(data: any): Promise<any> {
  return request(
    api.eventUrl + `/violating-subject/hncy/entities/closeStoreUpdateEntities`,
    {
      method: "POST",
      data,
      header: {
        'Content-Type': 'application/x-www-form-urlencoded'
    },
    }
  );
}
  // 专项巡查-查询动态字段
export async function specialProject(code: any): Promise<any> {
  return request(
    api.eventUrl + '/preprocessing/classify-info/getConditions?code=' + code,
    {
      method: "POST",
     
    }
  );
}

