import Taro from "@tarojs/taro";
import CryptoJS from "crypto-js"

/**
 * 根据&转为数组
 */
export const splitStrToArr = (str: string | undefined, sign: string = ",") => {
  if (str) {
    return str.split(sign);
  }
  return [];
};

//状态的动态颜色
export const caseStutsColor: Record<string, string> = {
  20: "#49C57D", //待受理
  30: "#3E6BDA", //待立案
  40: "#3E6BDA", //待派遣
  50: "#2FC7DA", //待处置
  60: "#2FC7DA", //处置中
  70: "#FFA748", //待核查
  80: "#C456F2", //待结案
  90: "#F56F6B", //已结案
  0: "#767B89", //已作废
  10: "#45B2FE", //预处理
  15: "#458AFE", //待直达
};

export function getAuth(
  authStr: keyof Taro.AuthSetting,
  refuseHint?: string,
  refuseCb?: () => void
) {
  return new Promise<boolean>((resolve) => {
    Taro.getSetting({
      success: (res) => {
        const flag = res.authSetting[authStr];
        if (flag) {
          resolve(true);
        } else {
          Taro.authorize({
            scope: authStr,
            success: () => {
              resolve(true);
            },
            fail: () => {
              resolve(false);
              if (refuseHint) {
                Taro.showModal({
                  title: "提示",
                  content: refuseHint,
                  confirmText: "去授权",
                  success: (res) => {
                    if (res.confirm) {
                      Taro.openSetting({
                        success: (res) => {},
                      });
                    } else {
                      refuseCb && refuseCb();
                    }
                  },
                });
              }
            },
          });
        }
      },
    });
  });
}

// 密码加密
export function encryption(src: string, keyWord: string) {
    const key = CryptoJS.enc.Utf8.parse(keyWord);
    var encrypted = CryptoJS.AES.encrypt(src, key, {
        iv: key,
        mode: CryptoJS.mode.CFB,
        padding: CryptoJS.pad.NoPadding,
    });
    return encrypted.toString();
}

// 获取URL中的参数
// export const getUrlParams = (url:string) => {
//   const search = new URL(url).search
//   const theRequest: any = new Object();
//   if (search.indexOf('?') != -1) {
//     const str = search.substr(1);
//     let strs = str.split('&');
//     for (let i = 0; i < strs.length; i++) {
//       theRequest[strs[i].split('=')[0]] = unescape(strs[i].split('=')[1]);
//     }
//   }
//   return theRequest;
// };

export function getUrlParams(url: string) {
    const queryParamsStr = url.split('?')[1] || '';
    const queryParamsArr = queryParamsStr.split('&');
    const paramsObj = {} as Record<string, any>;
    queryParamsArr.forEach(param => {
        const [key, value] = param.split('=');
        paramsObj[key] = decodeURIComponent(value);
    });
    return paramsObj;
}

// 对象转url参数
export function queryParams(data: any = {}, isPrefix = true, arrayFormat = 'brackets'): string {
  const prefix = isPrefix ? '?' : ''
  const _result: string[] = []
  if (['indices', 'brackets', 'repeat', 'comma'].indexOf(arrayFormat) == -1) arrayFormat = 'brackets'
  for (const key in data) {
      const value = data[key]
      // 去掉为空的参数
      if (['', undefined, null].indexOf(value) >= 0) {
          continue
      }
      // 如果值为数组，另行处理
      if (value.constructor === Array) {
          // e.g. {ids: [1, 2, 3]}
          switch (arrayFormat) {
              case 'indices':
                  // 结果: ids[0]=1&ids[1]=2&ids[2]=3
                  for (var i = 0; i < value.length; i++) {
                      _result.push(`${key}[${i}]=${value[i]}`)
                  }
                  break
              case 'brackets':
                  // 结果: ids[]=1&ids[]=2&ids[]=3
                  value.forEach((_value) => {
                      _result.push(`${key}[]=${_value}`)
                  })
                  break
              case 'repeat':
                  // 结果: ids=1&ids=2&ids=3
                  value.forEach((_value) => {
                      _result.push(`${key}=${_value}`)
                  })
                  break
              case 'comma':
                  // 结果: ids=1,2,3
                  var commaStr = ''
                  value.forEach((_value) => {
                      commaStr += (commaStr ? ',' : '') + _value
                  })
                  _result.push(`${key}=${commaStr}`)
                  break
              default:
                  value.forEach((_value) => {
                      _result.push(`${key}[]=${_value}`)
                  })
          }
      } else {
          _result.push(`${key}=${value}`)
      }
  }
  return _result.length ? prefix + _result.join('&') : ''
}


