import Taro from "@tarojs/taro"

const offCanvas = Taro.createOffscreenCanvas({
    type: '2d',
    width: 300,
    height: 300
})
const ctx = offCanvas.getContext('2d')
const fs = Taro.getFileSystemManager()
const dirPath = `${Taro.env.USER_DATA_PATH}/compress-img`

let filePath = ''
let imgWidth = 0
let imgHeight = 0
let imgSize = 0

const compressImg = {       // 图片大小kb
    async set(src: string, maxsize: number = 1024) {
        filePath = src
        let i = 0
        let istrue = false
        while (!istrue && i < 50) {
            i++;
            await new Promise((resolve) => {
                fs.getFileInfo({
                    filePath: filePath,
                    success: async (res) => {
                        imgSize = res.size
                        if (res.size > maxsize * 1024) {
                            await compressImg.compress(filePath)
                        } else {
                            await compressImg.compress(filePath, true)
                            istrue = true
                        }
                        resolve('')
                    }
                })
            });
        }
        return {
            filePath: filePath,
            width: imgWidth,
            height: imgHeight,
            size: imgSize,
        };
    },

    async compress(src: string, onlyGetWH: boolean = false) {
        const imageItem = offCanvas.createImage() // 图片对象
        imageItem.src = src // 设置图片src
        imageItem.onerror = err => {
            console.log('err', err)
            Taro.showModal({
                title: '提示',
                content: '照片加载失败',
                confirmText: '关闭',
                showCancel: false,
            })
        }

        // 如果图片已经存在于缓存
        if (imageItem.width > 0) {
            if (onlyGetWH) {
                imgWidth = imageItem.width;
                imgHeight = imageItem.height;
            } else {
                compressImg._imgLoaded(imageItem)
            }
        } else {
            await new Promise((resolve) => {
                imageItem.onload = () => {
                    if (onlyGetWH) {
                        imgWidth = imageItem.width;
                        imgHeight = imageItem.height;
                    } else {
                        compressImg._imgLoaded(imageItem)
                    }
                    resolve('')
                }
            });
        }
    },

    async _imgLoaded(img) {
        let yinzi = 0.95
        if (img.width > 2048 || img.height > 2048) yinzi = img.height > img.width ? (2048 / img.height) : (2048 / img.width)

        imgWidth = img.width * yinzi;
        imgHeight = img.height * yinzi;

        offCanvas.width = imgWidth
        offCanvas.height = imgHeight
        ctx.clearRect(0, 0, imgWidth, imgHeight);
        ctx.drawImage(img, 0, 0, img.width, img.height, 0, 0, offCanvas.width, offCanvas.height)

        fs.mkdir({
            dirPath: dirPath,
            recursive: false,
            // fail(res) {
            //   console.error(res)
            // }
        })

        const tempPath = `${dirPath}/${new Date().getTime()}.jpg`
        const dataURL = offCanvas.toDataURL('image/jpeg', 0.92).replace('data:image/jpeg;base64,', '')
        try {
            fs.writeFileSync(tempPath, dataURL, 'base64')
            filePath = tempPath
        } catch (e) {
            console.error(e)
        }
    },
    clearTempImg() {
        try {
            // 适当的时候删除临时文件
            Taro.getFileSystemManager().rmdir({
                dirPath: dirPath,
                recursive: true,
                // fail(res) {
                //   console.error(res)
                // }
            })
        } catch (error) {
            console.info(error)
        }
    }
}

export default {
    set: compressImg.set,
    clearTempImg: compressImg.clearTempImg
}